@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import copy
 import glob
 import os
 import posixpath
@@ -9,15 +10,13 @@ import re
 import sys
 from collections import ChainMap
 from contextlib import suppress
-from typing import Any, BinaryIO, Iterator, Optional, Tuple
+from typing import TYPE_CHECKING, Any, BinaryIO, Iterator, Mapping
 
-from griffe.agents.extensions import load_extensions
 from griffe.collections import LinesCollection, ModulesCollection
 from griffe.docstrings.parsers import Parser
 from griffe.exceptions import AliasResolutionError
 from griffe.loader import GriffeLoader
 from griffe.logger import patch_loggers
-from markdown import Markdown
 from mkdocstrings.extension import PluginError
 from mkdocstrings.handlers.base import BaseHandler, CollectionError, CollectorItem
 from mkdocstrings.inventory import Inventory
@@ -25,14 +24,24 @@ from mkdocstrings.loggers import get_logger
 
 from mkdocstrings_handlers.python import rendering
 
+try:
+    from griffe.extensions import load_extensions
+except ImportError:
+    # TODO: remove once support for Griffe 0.25 is dropped
+    from griffe.agents.extensions import load_extensions  # type: ignore[no-redef]
+
+if TYPE_CHECKING:
+    from markdown import Markdown
+
+
 if sys.version_info >= (3, 11):
     from contextlib import chdir
 else:
     # TODO: remove once support for Python 3.10 is dropped
     from contextlib import contextmanager
 
-    @contextmanager  # noqa: WPS440
-    def chdir(path: str):  # noqa: D103,WPS440
+    @contextmanager
+    def chdir(path: str) -> Iterator[None]:  # noqa: D103
         old_wd = os.getcwd()
         os.chdir(path)
         try:
@@ -78,6 +87,16 @@ class PythonHandler(BaseHandler):
         "separate_signature": False,
         "line_length": 60,
         "merge_init_into_class": False,
+        "show_docstring_attributes": True,
+        "show_docstring_description": True,
+        "show_docstring_examples": True,
+        "show_docstring_other_parameters": True,
+        "show_docstring_parameters": True,
+        "show_docstring_raises": True,
+        "show_docstring_receives": True,
+        "show_docstring_returns": True,
+        "show_docstring_warns": True,
+        "show_docstring_yields": True,
         "show_source": True,
         "show_bases": True,
         "show_submodules": False,
@@ -88,6 +107,8 @@ class PythonHandler(BaseHandler):
         "members": None,
         "filters": ["!^_[^_]"],
         "annotations_path": "brief",
+        "preload_modules": None,
+        "load_external_modules": False,
     }
     """
     Attributes: Headings options:
@@ -118,6 +139,16 @@ class PythonHandler(BaseHandler):
         line_length (int): Maximum line length when formatting code/signatures. Default: `60`.
         merge_init_into_class (bool): Whether to merge the `__init__` method into the class' signature and docstring. Default: `False`.
         show_if_no_docstring (bool): Show the object heading even if it has no docstring or children with docstrings. Default: `False`.
+        show_docstring_attributes (bool): Whether to display the "Attributes" section in the object's docstring. Default: `True`.
+        show_docstring_description (bool): Whether to display the textual block (including admonitions) in the object's docstring. Default: `True`.
+        show_docstring_examples (bool): Whether to display the "Examples" section in the object's docstring. Default: `True`.
+        show_docstring_other_parameters (bool): Whether to display the "Other Parameters" section in the object's docstring. Default: `True`.
+        show_docstring_parameters (bool): Whether to display the "Parameters" section in the object's docstring. Default: `True`.
+        show_docstring_raises (bool): Whether to display the "Raises" section in the object's docstring. Default: `True`.
+        show_docstring_receives (bool): Whether to display the "Receives" section in the object's docstring. Default: `True`.
+        show_docstring_returns (bool): Whether to display the "Returns" section in the object's docstring. Default: `True`.
+        show_docstring_warns (bool): Whether to display the "Warns" section in the object's docstring. Default: `True`.
+        show_docstring_yields (bool): Whether to display the "Yields" section in the object's docstring. Default: `True`.
 
     Attributes: Signatures/annotations options:
         annotations_path (str): The verbosity for annotations path: `brief` (recommended), or `source` (as written in the source). Default: `"brief"`.
@@ -129,10 +160,24 @@ class PythonHandler(BaseHandler):
     Attributes: Additional options:
         show_bases (bool): Show the base classes of a class. Default: `True`.
         show_source (bool): Show the source code of this object. Default: `True`.
-    """  # noqa: E501
+        preload_modules (list[str] | None): Pre-load modules that are
+            not specified directly in autodoc instructions (`::: identifier`).
+            It is useful when you want to render documentation for a particular member of an object,
+            and this member is imported from another package than its parent.
+
+            For an imported member to be rendered, you need to add it to the `__all__` attribute
+            of the importing module.
+
+            The modules must be listed as an array of strings. Default: `None`.
+
+    """
 
     def __init__(
-        self, *args: Any, config_file_path: str | None = None, paths: list[str] | None = None, **kwargs: Any
+        self,
+        *args: Any,
+        config_file_path: str | None = None,
+        paths: list[str] | None = None,
+        **kwargs: Any,
     ) -> None:
         """Initialize the handler.
 
@@ -153,9 +198,8 @@ class PythonHandler(BaseHandler):
             paths.append(os.path.dirname(config_file_path))
         search_paths = [path for path in sys.path if path]  # eliminate empty path
         for path in reversed(paths):
-            if not os.path.isabs(path):
-                if config_file_path:
-                    path = os.path.abspath(os.path.join(os.path.dirname(config_file_path), path))
+            if not os.path.isabs(path) and config_file_path:
+                path = os.path.abspath(os.path.join(os.path.dirname(config_file_path), path))  # noqa: PLW2901
             if path not in search_paths:
                 search_paths.insert(0, path)
         self._paths = search_paths
@@ -167,9 +211,10 @@ class PythonHandler(BaseHandler):
         cls,
         in_file: BinaryIO,
         url: str,
-        base_url: Optional[str] = None,
-        **kwargs: Any,
-    ) -> Iterator[Tuple[str, str]]:
+        base_url: str | None = None,
+        domains: list[str] | None = None,
+        **kwargs: Any,  # noqa: ARG003
+    ) -> Iterator[tuple[str, str]]:
         """Yield items and their URLs from an inventory file streamed from `in_file`.
 
         This implements mkdocstrings' `load_inventory` "protocol" (see [`mkdocstrings.plugin`][mkdocstrings.plugin]).
@@ -178,24 +223,28 @@ class PythonHandler(BaseHandler):
             in_file: The binary file-like object to read the inventory from.
             url: The URL that this file is being streamed from (used to guess `base_url`).
             base_url: The URL that this inventory's sub-paths are relative to.
+            domains: A list of domain strings to filter the inventory by, when not passed, "py" will be used.
             **kwargs: Ignore additional arguments passed from the config.
 
         Yields:
             Tuples of (item identifier, item URL).
         """
+        domains = domains or ["py"]
         if base_url is None:
             base_url = posixpath.dirname(url)
 
-        for item in Inventory.parse_sphinx(in_file, domain_filter=("py",)).values():  # noqa: WPS526
+        for item in Inventory.parse_sphinx(in_file, domain_filter=domains).values():
             yield item.name, posixpath.join(base_url, item.uri)
 
-    def collect(self, identifier: str, config: dict) -> CollectorItem:  # noqa: D102,WPS231
+    def collect(self, identifier: str, config: Mapping[str, Any]) -> CollectorItem:  # noqa: D102
         module_name = identifier.split(".", 1)[0]
         unknown_module = module_name not in self._modules_collection
         if config.get("fallback", False) and unknown_module:
             raise CollectionError("Not loading additional modules during fallback")
 
-        final_config = ChainMap(config, self.default_config)
+        # See: https://github.com/python/typeshed/issues/8430
+        mutable_config = dict(copy.deepcopy(config))
+        final_config = ChainMap(mutable_config, self.default_config)
         parser_name = final_config["docstring_style"]
         parser_options = final_config["docstring_options"]
         parser = parser_name and Parser(parser_name)
@@ -210,18 +259,26 @@ class PythonHandler(BaseHandler):
                 lines_collection=self._lines_collection,
             )
             try:
+                for pre_loaded_module in final_config.get("preload_modules") or []:
+                    if pre_loaded_module not in self._modules_collection:
+                        loader.load_module(pre_loaded_module)
                 loader.load_module(module_name)
             except ImportError as error:
                 raise CollectionError(str(error)) from error
-
-            unresolved, iterations = loader.resolve_aliases(implicit=False, external=False)
+            unresolved, iterations = loader.resolve_aliases(
+                implicit=False,
+                external=final_config["load_external_modules"],
+            )
             if unresolved:
-                logger.warning(f"{len(unresolved)} aliases were still unresolved after {iterations} iterations")
+                logger.debug(f"{len(unresolved)} aliases were still unresolved after {iterations} iterations")
+                logger.debug(f"Unresolved aliases: {', '.join(sorted(unresolved))}")
 
         try:
             doc_object = self._modules_collection[identifier]
-        except KeyError as error:  # noqa: WPS440
+        except KeyError as error:
             raise CollectionError(f"{identifier} could not be found") from error
+        except AliasResolutionError as error:
+            raise CollectionError(str(error)) from error
 
         if not unknown_module:
             with suppress(AliasResolutionError):
@@ -231,8 +288,10 @@ class PythonHandler(BaseHandler):
 
         return doc_object
 
-    def render(self, data: CollectorItem, config: dict) -> str:  # noqa: D102 (ignore missing docstring)
-        final_config = ChainMap(config, self.default_config)
+    def render(self, data: CollectorItem, config: Mapping[str, Any]) -> str:  # noqa: D102 (ignore missing docstring)
+        # See https://github.com/python/typeshed/issues/8430
+        mutabled_config = dict(copy.deepcopy(config))
+        final_config = ChainMap(mutabled_config, self.default_config)
 
         template = self.env.get_template(f"{data.kind.value}.html")
 
@@ -242,9 +301,11 @@ class PythonHandler(BaseHandler):
         heading_level = final_config["heading_level"]
         try:
             final_config["members_order"] = rendering.Order(final_config["members_order"])
-        except ValueError:
+        except ValueError as error:
             choices = "', '".join(item.value for item in rendering.Order)
-            raise PluginError(f"Unknown members_order '{final_config['members_order']}', choose between '{choices}'.")
+            raise PluginError(
+                f"Unknown members_order '{final_config['members_order']}', choose between '{choices}'.",
+            ) from error
 
         if final_config["filters"]:
             final_config["filters"] = [
@@ -275,11 +336,11 @@ class PythonHandler(BaseHandler):
 
 
 def get_handler(
-    theme: str,  # noqa: W0613 (unused argument config)
-    custom_templates: Optional[str] = None,
+    theme: str,
+    custom_templates: str | None = None,
     config_file_path: str | None = None,
     paths: list[str] | None = None,
-    **config: Any,
+    **config: Any,  # noqa: ARG001
 ) -> PythonHandler:
     """Simply return an instance of `PythonHandler`.
 
